@@ -2,7 +2,7 @@ from __future__ import annotations
 
 from typing import Any
 
-from ..types import FuncExceptT, SupportsString
+from ..types import FuncExcept, SupportsString
 from .base import CustomError
 
 __all__ = ["CustomImportError", "DependencyNotFoundError"]
@@ -13,15 +13,16 @@ class CustomImportError(CustomError, ImportError):
 
     def __init__(
         self,
-        func: FuncExceptT,
+        func: FuncExcept,
         package: str | ImportError,
         message: SupportsString = "Import failed for package '{package}'!",
         **kwargs: Any,
     ) -> None:
         """
-        :param func:        Function this error was raised from.
-        :param package:     Either the raised error or the name of the missing package.
-        :param message:     Custom error message.
+        Args:
+            func: Function this error was raised from.
+            package: Either the raised error or the name of the missing package.
+            message: Custom error message.
         """
 
         super().__init__(message, func, package=package if isinstance(package, str) else package.name, **kwargs)
@@ -32,7 +33,7 @@ class DependencyNotFoundError(CustomImportError):
 
     def __init__(
         self,
-        func: FuncExceptT,
+        func: FuncExcept,
         package: str | ImportError,
         message: SupportsString = "Missing dependency '{package}'!",
         **kwargs: Any,
